@@ -22,6 +22,13 @@
 
 #include "config.h"
 
+/**
+ * SECTION:glade-base-editor
+ * @Short_Description: A customisable editor
+ *
+ * Convenience object to edit containers where placeholders do not make sense, like GtkMenubar.
+ */
+
 #include "glade.h"
 #include "glade-editor-property.h"
 #include "glade-base-editor.h"
@@ -71,6 +78,8 @@ struct _GladeBaseEditorPrivate
 	gint row;
 	
 	gboolean updating_treeview;
+
+	guint properties_idle;
 };
 
 typedef struct _GladeBaseEditorSignal     GladeBaseEditorSignal;
@@ -343,7 +352,9 @@ glade_base_editor_treeview_cursor_changed (GtkTreeView *treeview,
 	GObject *child;
 	GladeWidget *gchild;
 
-	if (! glade_base_editor_get_child_selected (editor, &iter))
+	g_return_if_fail (GTK_IS_TREE_VIEW (treeview));
+
+	if (!glade_base_editor_get_child_selected (editor, &iter))
 		return;
 
 	glade_base_editor_clear (editor);
@@ -365,15 +376,21 @@ glade_base_editor_treeview_cursor_changed (GtkTreeView *treeview,
 static gboolean
 glade_base_editor_update_properties_idle (gpointer data)
 {
-       glade_base_editor_treeview_cursor_changed (NULL, (GladeBaseEditor *)data);
-       return FALSE;
+	GladeBaseEditor *editor = (GladeBaseEditor *)data;
+	glade_base_editor_treeview_cursor_changed (NULL, editor);
+	editor->priv->properties_idle = 0;
+	return FALSE;
 }
 
 
 static void 
 glade_base_editor_update_properties (GladeBaseEditor *editor)
 {
-       g_idle_add (glade_base_editor_update_properties_idle, editor);
+	g_return_if_fail (GLADE_IS_BASE_EDITOR (editor));
+
+	if (!editor->priv->properties_idle)
+		editor->priv->properties_idle = 
+			g_idle_add (glade_base_editor_update_properties_idle, editor);
 }
 
 static void
@@ -986,6 +1003,12 @@ glade_base_editor_project_disconnect (GladeBaseEditor *editor)
 	
 	g_signal_handlers_disconnect_by_func (e->project,
 			glade_base_editor_project_changed, editor);
+
+
+	if (e->properties_idle)
+		g_source_remove (e->properties_idle);
+	e->properties_idle = 0;
+
 }
 
 static void
@@ -1627,6 +1650,7 @@ glade_base_editor_add_default_properties (GladeBaseEditor *editor,
  * glade_base_editor_add_properties:
  * @editor: a #GladeBaseEditor
  * @gchild: a #GladeWidget
+ * @packing: whether we are adding packing properties or not
  * @...: A NULL terminated list of properties names.
  * 
  * Add @gchild properties to @editor
@@ -1635,7 +1659,8 @@ glade_base_editor_add_default_properties (GladeBaseEditor *editor,
  */
 void
 glade_base_editor_add_properties (GladeBaseEditor *editor,
-				  GladeWidget *gchild,
+				  GladeWidget     *gchild,
+				  gboolean         packing,
 				  ...)
 {
 	GladeEditorProperty *eprop;
@@ -1645,18 +1670,19 @@ glade_base_editor_add_properties (GladeBaseEditor *editor,
 	g_return_if_fail (GLADE_IS_BASE_EDITOR (editor));
 	g_return_if_fail (GLADE_IS_WIDGET (gchild));
 	
-	va_start (args, gchild);
+	va_start (args, packing);
 	property = va_arg (args, gchar *);
 	
 	while (property)
 	{
-		eprop = glade_editor_property_new_from_widget (gchild, property, TRUE);
+		eprop = glade_editor_property_new_from_widget (gchild, property, packing, TRUE);
 		if (eprop)
 			glade_base_editor_table_attach (editor, 
-							GLADE_EDITOR_PROPERTY (eprop)->eventbox, 
+							GLADE_EDITOR_PROPERTY (eprop)->item_label,
 							GTK_WIDGET (eprop));
 		property = va_arg (args, gchar *);
 	}
+	va_end (args);
 }
 
 /**
