@@ -26,9 +26,6 @@ struct _GladeEditorProperty
 
 	GtkWidget          *item_label;     /* Name of property (need a handle to set visual insensitive state)
 					     */
-	GtkWidget          *eventbox;       /* Eventbox on item_label.
-					     */
-
 	GtkWidget          *input;          /* Input part of property (need to set sensitivity seperately)
 					     */
 
@@ -55,12 +52,6 @@ struct _GladeEditorProperty
 	gboolean            show_info;      /* Whether we should show an informational button
 					     * for this property
 					     */
-
-	GdkColor           *insensitive_colour;	/* For setting insensitive background on   */
-	GdkColor           *normal_colour;      /* labels without setting them insensitive
-						 * (tooltips dont work on insensitive widgets
-						 * at this time)
-						 */
 };
 
 struct _GladeEditorPropertyClass {
